Module blaxel.core.client.models.jobs_success_failed_chart
==========================================================

Classes
-------

`JobsSuccessFailedChart(failed: blaxel.core.client.types.Unset | ForwardRef('JobsChartValue') = <blaxel.core.client.types.Unset object>, retried: blaxel.core.client.types.Unset | ForwardRef('JobsChartValue') = <blaxel.core.client.types.Unset object>, success: blaxel.core.client.types.Unset | ForwardRef('JobsChartValue') = <blaxel.core.client.types.Unset object>, timestamp: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, total: blaxel.core.client.types.Unset | ForwardRef('JobsChartValue') = <blaxel.core.client.types.Unset object>)`
:   Jobs chart
    
    Attributes:
        failed (Union[Unset, JobsChartValue]): Jobs CPU usage
        retried (Union[Unset, JobsChartValue]): Jobs CPU usage
        success (Union[Unset, JobsChartValue]): Jobs CPU usage
        timestamp (Union[Unset, str]): Metric timestamp
        total (Union[Unset, JobsChartValue]): Jobs CPU usage
    
    Method generated by attrs for class JobsSuccessFailedChart.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `failed`
    :

    `retried`
    :

    `success`
    :

    `timestamp`
    :

    `total`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :